"""
rapid string matching library
"""
__author__ = "Max Bachmann"
__license__ = "MIT"
__version__ = "0.13.2"

from rapidfuzz import process, fuzz, utils, levenshtein
